@@ -148,15 +148,14 @@ pub fn run(arg: PathBuf) {
                         clear_and_show(&current_dir);
                         state.list_up(nums.skip);
                         print!("{}>{}", cursor::Goto(1, row - 1), cursor::Left(1));
-                        nums.go_bottom(len - 1);
                     } else {
                         print!(
                             " {}>{}",
                             cursor::Goto(1, len as u16 + STARTING_POINT - 1),
                             cursor::Left(1)
                         );
-                        nums.go_bottom(len - 1);
                     }
+                    nums.go_bottom(len - 1);
                 }
 
                 //Open file or change directory
@@ -165,8 +164,9 @@ pub fn run(arg: PathBuf) {
                         match item.file_type {
                             FileType::File | FileType::Symlink => {
                                 print!("{}", screen::ToAlternateScreen);
-                                if let Err(e) = state.open_file(nums.index) {
-                                    print_warning(e, y);
+                                if state.open_file(nums.index).is_err() {
+                                    print_warning("Cannot open file. Check your config!", y);
+                                    continue;
                                 }
                                 print!("{}", screen::ToAlternateScreen);
                                 clear_and_show(&current_dir);
@@ -1036,31 +1036,37 @@ pub fn run(arg: PathBuf) {
                                         break 'command;
                                     }
 
-                                    if c == "cd" {
-                                        current_dir =
-                                            PathBuf::from(args[0]).canonicalize().unwrap();
-                                        std::env::set_current_dir(&current_dir)
-                                            .unwrap_or_else(|e| print_warning(e, y));
-                                        state.update_list(&current_dir);
-                                        clear_and_show(&current_dir);
-                                        state.list_up(0);
-                                        print!(
-                                            "{}{}>{}",
-                                            cursor::Hide,
-                                            cursor::Goto(1, STARTING_POINT),
-                                            cursor::Left(1),
-                                        );
-                                        nums.reset();
-                                        break 'command;
-                                    }
+                                    // if c == "cd" {
+                                    //     current_dir =
+                                    //         PathBuf::from(args[0]).canonicalize().unwrap();
+                                    //     state.update_list(&current_dir);
+                                    //     clear_and_show(&current_dir);
+                                    //     state.list_up(0);
+                                    //     print!(
+                                    //         "{}{}>{}",
+                                    //         cursor::Hide,
+                                    //         cursor::Goto(1, STARTING_POINT),
+                                    //         cursor::Left(1),
+                                    //     );
+                                    //     nums.reset();
+                                    //     break 'command;
+                                    // }
 
                                     print!("{}", screen::ToAlternateScreen);
                                     std::env::set_current_dir(&current_dir)
                                         .unwrap_or_else(|e| print_warning(e, y));
-                                    if let Err(e) =
+                                    if let Err(_) =
                                         std::process::Command::new(c).args(args).status()
                                     {
-                                        print_warning(e, y);
+                                        print!("{}", screen::ToAlternateScreen);
+
+                                        clear_and_show(&current_dir);
+                                        state.update_list(&current_dir);
+                                        state.list_up(nums.skip);
+
+                                        print!("{}", cursor::Hide,);
+                                        print_warning("cannot execute command", y);
+                                        break 'command;
                                     }
                                     print!("{}", screen::ToAlternateScreen);
 
